Class: Aws::CloudSearchDomain::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CloudSearchDomain::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-cloudsearchdomain/client.rb,
sig/client.rbs
Overview
An API client for CloudSearchDomain. To construct a client, you need to configure a :region and :credentials.
client = Aws::CloudSearchDomain::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _SearchResponseSuccess, _SuggestResponseSuccess, _UploadDocumentsResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#search(params = {}) ⇒ Types::SearchResponse
Retrieves a list of documents that match the specified search criteria.
-
#suggest(params = {}) ⇒ Types::SuggestResponse
Retrieves autocomplete suggestions for a partial query string.
-
#upload_documents(params = {}) ⇒ Types::UploadDocumentsResponse
Posts a batch of documents to a search domain for indexing.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
411 412 413 |
# File 'lib/aws-sdk-cloudsearchdomain/client.rb', line 411 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1034 1035 1036 |
# File 'lib/aws-sdk-cloudsearchdomain/client.rb', line 1034 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1037 1038 1039 |
# File 'lib/aws-sdk-cloudsearchdomain/client.rb', line 1037 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 |
# File 'lib/aws-sdk-cloudsearchdomain/client.rb', line 1007 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CloudSearchDomain') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-cloudsearchdomain' context[:gem_version] = '1.74.0' Seahorse::Client::Request.new(handlers, context) end |
#search(params = {}) ⇒ Types::SearchResponse
Retrieves a list of documents that match the specified search criteria. How you specify the search criteria depends on which query parser you use. Amazon CloudSearch supports four query parsers:
simple: search alltextandtext-arrayfields for the specified string. Search for phrases, individual terms, and prefixes.structured: search specific fields, construct compound queries using Boolean operators, and use advanced features such as term boosting and proximity searching.lucene: specify search criteria using the Apache Lucene query parser syntax.dismax: specify search criteria using the simplified subset of the Apache Lucene query parser syntax defined by the DisMax query parser.
For more information, see Searching Your Data in the Amazon CloudSearch Developer Guide.
The endpoint for submitting Search requests is domain-specific. You
submit search requests to a domain's search endpoint. To get the
search endpoint for your domain, use the Amazon CloudSearch
configuration service DescribeDomains action. A domain's endpoints
are also displayed on the domain dashboard in the Amazon CloudSearch
console.
77 |
# File 'sig/client.rbs', line 77
def search: (
|
#suggest(params = {}) ⇒ Types::SuggestResponse
Retrieves autocomplete suggestions for a partial query string. You can use suggestions enable you to display likely matches before users finish typing. In Amazon CloudSearch, suggestions are based on the contents of a particular text field. When you request suggestions, Amazon CloudSearch finds all of the documents whose values in the suggester field start with the specified query string. The beginning of the field must match the query string to be considered a match.
For more information about configuring suggesters and retrieving suggestions, see Getting Suggestions in the Amazon CloudSearch Developer Guide.
The endpoint for submitting Suggest requests is domain-specific. You
submit suggest requests to a domain's search endpoint. To get the
search endpoint for your domain, use the Amazon CloudSearch
configuration service DescribeDomains action. A domain's endpoints
are also displayed on the domain dashboard in the Amazon CloudSearch
console.
101 |
# File 'sig/client.rbs', line 101
def suggest: (
|
#upload_documents(params = {}) ⇒ Types::UploadDocumentsResponse
Posts a batch of documents to a search domain for indexing. A document batch is a collection of add and delete operations that represent the documents you want to add, update, or delete from your domain. Batches can be described in either JSON or XML. Each item that you want Amazon CloudSearch to return as a search result (such as a product) is represented as a document. Every document has a unique ID and one or more fields that contain the data that you want to search and return in results. Individual documents cannot contain more than 1 MB of data. The entire batch cannot exceed 5 MB. To get the best possible upload performance, group add and delete operations in batches that are close the 5 MB limit. Submitting a large volume of single-document batches can overload a domain's document service.
The endpoint for submitting UploadDocuments requests is
domain-specific. To get the document endpoint for your domain, use the
Amazon CloudSearch configuration service DescribeDomains action. A
domain's endpoints are also displayed on the domain dashboard in the
Amazon CloudSearch console.
For more information about formatting your data for Amazon CloudSearch, see Preparing Your Data in the Amazon CloudSearch Developer Guide. For more information about uploading data for indexing, see Uploading Data in the Amazon CloudSearch Developer Guide.
116 |
# File 'sig/client.rbs', line 116
def upload_documents: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1027 1028 1029 |
# File 'lib/aws-sdk-cloudsearchdomain/client.rb', line 1027 def waiter_names [] end |