Class: Aws::CloudSearchDomain::Types::Bucket
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudSearchDomain::Types::Bucket
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudsearchdomain/types.rb
Overview
A container for facet information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#count ⇒ Integer
The number of hits that contain the facet value in the specified facet field.
-
#value ⇒ String
The facet value being counted.
Instance Attribute Details
#count ⇒ Integer
The number of hits that contain the facet value in the specified facet field.
24 25 26 27 28 29 |
# File 'lib/aws-sdk-cloudsearchdomain/types.rb', line 24 class Bucket < Struct.new( :value, :count) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The facet value being counted.
24 25 26 27 28 29 |
# File 'lib/aws-sdk-cloudsearchdomain/types.rb', line 24 class Bucket < Struct.new( :value, :count) SENSITIVE = [] include Aws::Structure end |